@@ -1,6 +1,7 @@
 use std::alloc::Layout;
 use std::fmt::{Debug, Display, Formatter};
 use std::ops::{Add, Deref, DerefMut, Sub};
+use std::time::SystemTime;
 use once_cell::sync::Lazy;
 use serde::de::Error;
 use time::{format_description, OffsetDateTime, UtcOffset};
@@ -8,16 +9,20 @@ use time::error::InvalidFormatDescription;
 use time::format_description::FormatItem;
 use crate::std::time::format::{longDayNames, longMonthNames};
 use crate::std::errors::Result;
+use crate::std::time::sys::Timespec;
 
 /// "Mon, 02 Jan 2006 15:04:05 GMT"
-pub const TimeFormat: &'static str = "[weekday], [day] [month] [year] [hour]:[minute]:[second] GMT";
+pub const TimeFormat: &'static str = "[weekday repr:short], [day] [month repr:short] [year] [hour]:[minute]:[second] GMT";
 /// "2006-01-02T15:04:05Z07:00"
 pub const RFC3339: &'static str = "[year]-[month]-[day]T[hour]:[minute]:[second][offset_hour sign:mandatory]:[offset_minute]";
 ///"2006-01-02T15:04:05.999999999Z07:00"
 pub const RFC3339Nano: &'static str = "[year]-[month]-[day]T[hour]:[minute]:[second].[subsecond][offset_hour sign:mandatory]:[offset_minute]";
+///"Mon, 02 Jan 2006 15:04:05 MST"
+pub const RFC1123: &'static str = "[weekday repr:short], [day] [month repr:short] [year] [hour]:[minute]:[second] MST";
 
-pub const GLOBAL_OFFSET: Lazy<UtcOffset> = Lazy::new(|| {
-    UtcOffset::from_whole_seconds(chrono::offset::Local::now().offset().local_minus_utc()).unwrap()
+/// Obtain the offset of Utc time and Local time in seconds, using Lazy only once to improve performance
+pub static GLOBAL_OFFSET: Lazy<UtcOffset> = Lazy::new(|| {
+    UtcOffset::from_whole_seconds(Timespec::now().local().tm_utcoff).unwrap()
 });
 
 /// a time wrapper just like golang
@@ -27,6 +32,20 @@ pub struct Time {
 }
 
 impl Time {
+    /// convert self to utc time
+    pub fn utc(&self) -> Self {
+        Self {
+            inner: self.inner.to_offset(UtcOffset::UTC)
+        }
+    }
+
+    /// convert self to utc time
+    pub fn local(&self) -> Self {
+        Self {
+            inner: self.inner.to_offset(GLOBAL_OFFSET.deref().clone())
+        }
+    }
+
     pub fn unix_timestamp(&self) -> i64 {
         self.inner.unix_timestamp()
     }
@@ -83,7 +102,7 @@ impl Time {
     /// is_zero reports whether t represents the zero time instant,
     /// January 1, year 1, 00:00:00 UTC.
     pub fn is_zero(&self) -> bool {
-        return self.unix_timestamp() == 0;
+        return self.nanosecond() == 0;
     }
 
     /// date returns the (year, month,  day) in which t occurs.
@@ -146,7 +165,7 @@ impl Time {
     }
 
     /// for example:
-    /// "[year]-[month]-[day] [hour]:[minute]:[second] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
+    /// "[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
     ///
     pub fn format(&self, layout: &str) -> String {
         let f = {
@@ -166,7 +185,7 @@ impl Time {
     }
 
     /// for example:
-    /// "[year]-[month]-[day] [hour]:[minute]:[second] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
+    /// "[year]-[month] [ordinal] [weekday] [week_number]-[day] [hour]:[minute] [period]:[second].[subsecond] [offset_hour sign:mandatory]:[offset_minute]:[offset_second]"
     ///
     pub fn parse(layout: &str, value: &str) -> Result<Self> {
         match format_description::parse(layout) {
@@ -210,6 +229,12 @@ impl Display for Time {
     }
 }
 
+impl Default for Time {
+    fn default() -> Self {
+        Self::parse(RFC3339Nano, "0001-01-01T00:00:00.000000+00:00").unwrap()
+    }
+}
+
 impl serde::Serialize for Time {
     fn serialize<S>(&self, serializer: S) -> std::result::Result<S::Ok, S::Error> where S: serde::Serializer {
         serializer.serialize_str(&self.format(RFC3339Nano))
